Reads a few sequence headers from a FASTA file and guesses the taxonomy format based on characteristic patterns.
Examples
db <- system.file("extdata", "example_unite.fasta", package = "dbpq")
detect_tax_format(db)
#> [1] "unite"
Reads a few sequence headers from a FASTA file and guesses the taxonomy format based on characteristic patterns.
db <- system.file("extdata", "example_unite.fasta", package = "dbpq")
detect_tax_format(db)
#> [1] "unite"